@@ -1,8 +1,7 @@
-import mock
 import urllib2
 import unittest
-from datetime import date
-from decimal import Decimal
+
+import mock
 from generic_request_signer import client
 
 
@@ -40,13 +39,13 @@ class ClientTests(unittest.TestCase):
     def test_get_response_invokes_urlopen_with_request_return_value(self):
         with mock.patch.object(self.sut_class, '_get_request') as get_request:
             self.sut._get_response('GET', '/', {}, **{})
-        self.urlopen.assert_called_once_with(get_request.return_value)
+        self.urlopen.assert_called_once_with(get_request.return_value, timeout=60)
 
     def test_get_response_invokes_get_request_incoming_params(self):
         method = 'GET'
         endpoint = '/'
-        data = {'some':'data'}
-        kwargs = {'some':'kwarg'}
+        data = {'some': 'data'}
+        kwargs = {'some': 'kwarg'}
         with mock.patch.object(self.sut_class, '_get_request') as get_request:
             self.sut._get_response(method, endpoint, data, **kwargs)
         get_request.assert_called_once_with(method, endpoint, data, None, **kwargs)
@@ -57,7 +56,7 @@ class ClientTests(unittest.TestCase):
         self.response.assert_called_once_with(self.urlopen.return_value)
 
     def test_when_urlopen_throws_exception_the_http_error_is_used_to_instantiate_the_response(self):
-        http_error = urllib2.HTTPError('/',500,'',None,None)
+        http_error = urllib2.HTTPError('/', 500, '', None, None)
         self.urlopen.side_effect = http_error
         with mock.patch.object(self.sut_class, '_get_request'):
             self.sut._get_response('GET', '/', {}, **{})
@@ -68,6 +67,18 @@ class ClientTests(unittest.TestCase):
             result = self.sut._get_response('GET', '/', {}, **{})
         self.assertEqual(result, self.response.return_value)
 
+    @mock.patch('urllib2.urlopen')
+    @mock.patch.object(client.Client, '_get_request')
+    def test_get_response_passes_default_timeout_to_url_open(self, get_request, urlopen):
+        self.sut._get_response('GET', '/', {}, **{})
+        urlopen.assert_called_once_with(get_request.return_value, timeout=60)
+
+    @mock.patch('urllib2.urlopen')
+    @mock.patch.object(client.Client, '_get_request')
+    def test_get_response_passes_passed_timeout_to_url_open(self, get_request, urlopen):
+        self.sut._get_response('GET', '/', {}, **{'timeout': 20})
+        urlopen.assert_called_once_with(get_request.return_value, timeout=20)
+
     def test_get_request_instantiates_factory_with_params(self):
         with mock.patch('generic_request_signer.factory.SignedRequestFactory') as factory:
             self.sut._get_request('GET', '/', {}, **{})
@@ -79,7 +90,7 @@ class ClientTests(unittest.TestCase):
         factory.assert_called_once_with('GET', '1', 'YQ==', {}, {'f': ('f', 'f')})
 
     def test_get_request_invokes_create_request_on_factory(self):
-        data = {'some':'data'}
+        data = {'some': 'data'}
         with mock.patch('generic_request_signer.factory.SignedRequestFactory') as factory:
             self.sut._get_request('GET', '/endpoint/', data, **{})
         factory.return_value.create_request.assert_called_once_with('/foo/endpoint/')
